==> certificatemanager-0.26.0-sources.jar: software/amazon/awscdk/services/certificatemanager/CertificateImportProps.java <==
package software.amazon.awscdk.services.certificatemanager;

/**
 * Reference to an existing Certificate
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T13:02:58.578Z")
public interface CertificateImportProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * The certificate's ARN
     */
    java.lang.String getCertificateArn();
    /**
     * The certificate's ARN
     */
    void setCertificateArn(final java.lang.String value);

    /**
     * @return a {@link Builder} of {@link CertificateImportProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CertificateImportProps}
     */
    final class Builder {
        private java.lang.String _certificateArn;

        /**
         * Sets the value of CertificateArn
         * @param value The certificate's ARN
         * @return {@code this}
         */
        public Builder withCertificateArn(final java.lang.String value) {
            this._certificateArn = java.util.Objects.requireNonNull(value, "certificateArn is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CertificateImportProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public CertificateImportProps build() {
            return new CertificateImportProps() {
                private java.lang.String $certificateArn = java.util.Objects.requireNonNull(_certificateArn, "certificateArn is required");

                @Override
                public java.lang.String getCertificateArn() {
                    return this.$certificateArn;
                }

                @Override
                public void setCertificateArn(final java.lang.String value) {
                    this.$certificateArn = java.util.Objects.requireNonNull(value, "certificateArn is required");
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.certificatemanager.CertificateImportProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The certificate's ARN
         */
        @Override
        public java.lang.String getCertificateArn() {
            return this.jsiiGet("certificateArn", java.lang.String.class);
        }

        /**
         * The certificate's ARN
         */
        @Override
        public void setCertificateArn(final java.lang.String value) {
            this.jsiiSet("certificateArn", java.util.Objects.requireNonNull(value, "certificateArn is required"));
        }
    }
}

==> certificatemanager-0.28.0-sources.jar: software/amazon/awscdk/services/certificatemanager/CertificateImportProps.java <==
package software.amazon.awscdk.services.certificatemanager;

/**
 * Reference to an existing Certificate
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-04-04T15:10:52.015Z")
public interface CertificateImportProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * The certificate's ARN
     */
    java.lang.String getCertificateArn();

    /**
     * @return a {@link Builder} of {@link CertificateImportProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CertificateImportProps}
     */
    final class Builder {
        private java.lang.String _certificateArn;

        /**
         * Sets the value of CertificateArn
         * @param value The certificate's ARN
         * @return {@code this}
         */
        public Builder withCertificateArn(final java.lang.String value) {
            this._certificateArn = java.util.Objects.requireNonNull(value, "certificateArn is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CertificateImportProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public CertificateImportProps build() {
            return new CertificateImportProps() {
                private final java.lang.String $certificateArn = java.util.Objects.requireNonNull(_certificateArn, "certificateArn is required");

                @Override
                public java.lang.String getCertificateArn() {
                    return this.$certificateArn;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("certificateArn", om.valueToTree(this.getCertificateArn()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.certificatemanager.CertificateImportProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The certificate's ARN
         */
        @Override
        public java.lang.String getCertificateArn() {
            return this.jsiiGet("certificateArn", java.lang.String.class);
        }
    }
}
